@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgfibs.cpp 384584 2005-01-31 15:35:48Z coles $
+  $Id: kbgfibs.cpp 465369 2005-09-29 14:33:08Z mueller $
 
 */
 
@@ -642,7 +642,7 @@ bool KBgEngineFIBS::queryClose()
 	if (connection->state() == QSocket::Idle)
 		return true;
 
-	switch (KMessageBox::warningYesNoCancel((QWidget *)parent(),i18n("Still connected. Log out first?"))) {
+	switch (KMessageBox::warningYesNoCancel((QWidget *)parent(),i18n("Still connected. Log out first?"),QString::null,i18n("Log Out"), i18n("Stay Connected"))) {
 	case KMessageBox::Yes :
 		disconnectFIBS();
 		return true;
